@@ -3,14 +3,14 @@
 Celery AMQP Administration Tool using the AMQP API.
 
 """
-from django.core.management.base import BaseCommand
-
 from celery.bin.camqadm import camqadm, OPTION_LIST
 
+from djcelery.management.base import CeleryCommand
 
-class Command(BaseCommand):
+
+class Command(CeleryCommand):
     """Run the celery daemon."""
-    option_list = BaseCommand.option_list + OPTION_LIST
+    option_list = CeleryCommand.option_list + OPTION_LIST
     help = 'Celery AMQP Administration Tool using the AMQP API.'
 
     def handle(self, *args, **options):
