@@ -31,7 +31,7 @@ def transaction_retry(max_retries=1):
             for retries in count(0):
                 try:
                     return fun(*args, **kwargs)
-                except Exception: # pragma: no cover
+                except Exception:   # pragma: no cover
                     # Depending on the database backend used we can experience
                     # various exceptions. E.g. psycopg2 raises an exception
                     # if some operation breaks the transaction, so saving
@@ -77,15 +77,19 @@ class ExtendedManager(models.Manager):
 
 class ResultManager(ExtendedManager):
 
-    def get_all_expired(self):
+    def get_all_expired(self, expires):
         """Get all expired task results."""
-        from celery import conf
-        expires = conf.TASK_RESULT_EXPIRES
         return self.filter(date_done__lt=datetime.now() - expires)
 
-    def delete_expired(self):
+    def delete_expired(self, expires):
         """Delete all expired taskset results."""
-        self.get_all_expired().delete()
+        self.get_all_expired(expires).delete()
+
+
+class PeriodicTaskManager(ExtendedManager):
+
+    def enabled(self):
+        return self.filter(enabled=True)
 
 
 class TaskManager(ResultManager):
@@ -131,10 +135,10 @@ class TaskManager(ResultManager):
             create the same task. The default is to retry twice.
 
         """
-        return self.update_or_create(task_id=task_id, defaults={
-                                        "status": status,
-                                        "result": result,
-                                        "traceback": traceback})
+        return self.update_or_create(task_id=task_id,
+                                     defaults={"status": status,
+                                               "result": result,
+                                               "traceback": traceback})
 
     def warn_if_repeatable_read(self):
         if settings.DATABASE_ENGINE.lower() == "mysql":
@@ -152,14 +156,12 @@ class TaskManager(ResultManager):
 class TaskSetManager(ResultManager):
     """Manager for :class:`celery.models.TaskSet` models."""
 
-
-    @transaction_retry(max_retries=1)
     def restore_taskset(self, taskset_id):
         """Get taskset meta for task by ``taskset_id``."""
         try:
             return self.get(taskset_id=taskset_id)
         except self.model.DoesNotExist:
-            return None
+            pass
 
     @transaction_retry(max_retries=2)
     def store_result(self, taskset_id, result):
@@ -172,3 +174,19 @@ class TaskSetManager(ResultManager):
         """
         return self.update_or_create(taskset_id=taskset_id,
                                      defaults={"result": result})
+
+
+class TaskStateManager(ExtendedManager):
+
+    def active(self):
+        return self.filter(hidden=False)
+
+    def expired(self, states, expires):
+        return self.filter(state__in=states,
+                           tstamp__lte=datetime.now() - expires)
+
+    def expire_by_states(self, states, expires):
+        return self.expired(states, expires).update(hidden=True)
+
+    def purge(self):
+        self.filter(hidden=True).delete()
