@@ -6,6 +6,7 @@ from time import time
 
 from anyjson import deserialize, serialize
 from django.db import transaction
+from django.core.exceptions import ObjectDoesNotExist
 
 from celery import schedules
 from celery.beat import Scheduler, ScheduleEntry
@@ -41,9 +42,12 @@ class ModelEntry(ScheduleEntry):
         self.model = model
 
         if not model.last_run_at:
-            model.last_run_at = datetime.now()
+            model.last_run_at = self._default_now()
         self.last_run_at = model.last_run_at
 
+    def _default_now(self):
+        return datetime.now()
+
     def next(self):
         self.model.last_run_at = datetime.now()
         self.model.total_run_count += 1
@@ -149,7 +153,7 @@ class DatabaseScheduler(Scheduler):
                 try:
                     name = self._dirty.pop()
                     self.schedule[name].save()
-                except KeyError:
+                except (KeyError, ObjectDoesNotExist):
                     continue
         except:
             transaction.rollback()
