@@ -1,5 +1,3 @@
-import unittest2 as unittest
-
 from datetime import datetime, timedelta
 
 from celery import conf
@@ -9,6 +7,7 @@ from celery.task import PeriodicTask
 from celery.utils import gen_unique_id
 
 from djcelery.backends.database import DatabaseBackend
+from djcelery.tests.utils import unittest
 
 
 class SomeClass(object):
