@@ -1,4 +1,3 @@
-import unittest2 as unittest
 from datetime import datetime, timedelta
 
 from celery import conf
@@ -6,6 +5,7 @@ from celery import states
 from celery.utils import gen_unique_id
 
 from djcelery.models import TaskMeta, TaskSetMeta
+from djcelery.tests.utils import unittest
 
 
 class TestModels(unittest.TestCase):
