@@ -1,4 +1,6 @@
 # Django settings for demoproject project.
+import djcelery
+djcelery.setup_loader()
 
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
@@ -7,7 +9,7 @@ ADMINS = (
     # ('Your Name', 'your_email@domain.com'),
 )
 
-CELERY_RESULT_BACKEND = "amqp"
+CELERY_RESULT_BACKEND = "database"
 BROKER_HOST = "localhost"
 BROKER_PORT = 5672
 BROKER_USER = "guest"
